"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.initializeSourceControlManager = exports.sourceControlPush = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _path = require("path");

var _chalk = _interopRequireDefault(require("chalk"));

var _exec = require("./exec");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint no-console: 0 */
const generateCloses = closes => {
  let closesString = '';

  for (const close of closes) {
    closesString += `#${close}, `;
  }

  return closesString.substring(0, closesString.length - 2);
};

const generateBreaking = breaking => breaking ? 'BREAKING CHANGE' : '';

const generateStandardCommitMessage = // eslint-disable-next-line
(type, scope, message, closes, breaking) => ({
  title: `${type}(${scope}): ${message}`,
  description: closes.length > 0 ? `${generateCloses(closes)}\n${generateBreaking(breaking)}` : `${generateBreaking(breaking)}\n`
});

const sourceControlPush = // eslint-disable-next-line
async (branch, type, scope, message, closes, breaking = false) => {
  try {
    console.log(_chalk.default.blue(`Checking out ${branch}`));
    const result = await (0, _exec.shellExec)(`git checkout -b ${branch}`);
    console.log(_chalk.default.green(result.stdout));
    console.log(_chalk.default.red(result.stderr));
  } catch (err) {
    console.log((0, _chalk.default)(err));
  }

  try {
    console.log(_chalk.default.blue(`Adding all updated files to ${branch}`));
    const result = await (0, _exec.shellExec)(`git add -A`);
    console.log(_chalk.default.green(result.stdout));
    console.log(_chalk.default.red(result.stderr));
  } catch (err) {
    console.log((0, _chalk.default)(err));
  }

  try {
    const commitMessage = generateStandardCommitMessage(type, scope, message, closes, breaking);
    console.log(_chalk.default.blue( // eslint-disable-next-line
    `Adding commit message: \n${commitMessage}`));
    const result = await (0, _exec.shellExec)(`git add -A`);
    console.log(_chalk.default.green(result.stdout));
    console.log(_chalk.default.red(result.stderr));
  } catch (err) {
    console.log((0, _chalk.default)(err));
  }
};

exports.sourceControlPush = sourceControlPush;

const initializeSourceControlManager = // eslint-disable-next-line
async (projectName, repoOwner, branch, withGitIgnore = false) => {
  let result = null;
  console.log('----------------************************ INITIALIZING BRANCH', {
    branch
  });

  if (branch === 'master') {
    try {
      result = await (0, _exec.shellExec)(`git init`);
      console.log(_chalk.default.red(result.stderr));
      console.log(_chalk.default.green(result.stdout));
    } catch (err) {
      console.log(_chalk.default.red(err));
    }

    try {
      result = await (0, _exec.shellExec)(`git remote add origin https://github.com/${repoOwner}/${projectName}.git`);
      console.log(_chalk.default.red(result.stderr));
      console.log(_chalk.default.green(result.stdout));
    } catch (err) {
      console.log(_chalk.default.yellow(err));
    }
  }

  if (withGitIgnore) {
    const outFileName = (0, _path.join)(process.cwd(), '.gitignore');
    const sourceDir = (0, _path.join)((0, _path.dirname)(process.argv[1]), 'templates');

    _fs.default.copyFileSync((0, _path.join)(sourceDir, '.gitignore'), outFileName);

    console.log(_chalk.default.green('Copied .gitignore'));
  }

  try {
    result = await (0, _exec.shellExec)(`git remote add origin https://github.com/${repoOwner}/${projectName}.git`);
    console.log(_chalk.default.red(result.stderr));
    console.log(_chalk.default.green(result.stdout));
  } catch (err) {
    console.log(_chalk.default.yellow(err));
  }
};

exports.initializeSourceControlManager = initializeSourceControlManager;